@@ -1,6 +1,6 @@
 selection_nonsparse = function(obj,burn.in=obj$burn.in){
-  sg1 = obj$posterior$GS.beta
-  sg2 = obj$posterior$GS.eta
+  sg1 = obj$posterior$GS.gamma2
+  sg2 = obj$posterior$GS.gamma3
   q_t1=c()
   for(j in 1:ncol(sg1)){
     t1=as.matrix(sg1[,j])
@@ -15,6 +15,6 @@ selection_nonsparse = function(obj,burn.in=obj$burn.in){
     q_t2 = as.matrix(stats::quantile(t2,c(0.025,0.975)))
   }
  inter = apply(q_t2, 2, fun)
- inde = c(main,inter)
- inde
+ index = c(main,inter)
+ index
 }
